@@ -26,7 +26,7 @@ knn1 <- function(train, test, cl)
 		as.integer(nc),
 		d = double(nte)
 		)$res
-	factor(res, levels=seq(along=levels(clf)), labels=levels(clf))
+	factor(res, levels=seq_along(levels(clf)), labels=levels(clf))
 }
 
 knn <- function(train, test, cl, k=1, l=0, prob=FALSE, use.all=TRUE)
@@ -66,7 +66,7 @@ knn <- function(train, test, cl, k=1, l=0, prob=FALSE, use.all=TRUE)
 		as.integer(FALSE),
 		as.integer(use.all)
 		)
-	res <- factor(Z$res, levels=seq(along=levels(clf)),labels=levels(clf))
+	res <- factor(Z$res, levels=seq_along(levels(clf)),labels=levels(clf))
 	if(prob) attr(res, "prob") <- Z$pr
 	res
 }
@@ -104,7 +104,7 @@ knn.cv <- function(train, cl, k=1, l=0, prob=FALSE, use.all=TRUE)
 		as.integer(TRUE),
 		as.integer(use.all)
 		)
-	res <- factor(Z$res, levels=seq(along=levels(clf)),labels=levels(clf))
+	res <- factor(Z$res, levels=seq_along(levels(clf)),labels=levels(clf))
 	if(prob) attr(res, "prob") <- Z$pr
 	res
 }
